# frozen_string_literal: true

module Phlex::Rails::Helpers::DistanceOfTimeInWordsToNow
	extend Phlex::Rails::HelperMacros

	# [Rails Docs](https://api.rubyonrails.org/classes/ActionView/Helpers/DateHelper.html#method-i-distance_of_time_in_words_to_now)
	register_value_helper def distance_of_time_in_words_to_now(...) = nil
end
