# frozen_string_literal: true

module Phlex::Rails::Helpers::L
	extend Phlex::Rails::HelperMacros

	# [Rails Docs](https://api.rubyonrails.org/classes/ActionView/Helpers/TranslationHelper.html#method-i-l)
	register_value_helper def l(...) = nil
end
