# frozen_string_literal: true

module Phlex::Rails::Helpers::BuildTagValues
	extend Phlex::Rails::HelperMacros

	# [Rails Docs](https://api.rubyonrails.org/classes/ActionView/Helpers/TagHelper.html#method-c-build_tag_values)
	register_value_helper def build_tag_values(...) = nil
end
