# frozen_string_literal: true

class Views::<%= "#{namespace}::" if namespaced? %><%= class_name %> < Views::Base
  def view_template
    h1 { "<%= class_name %>" }
    p { "Find me in <%= @view_path %>" }
  end
end
