# frozen_string_literal: true

module Phlex::Rails::Helpers::JavaScriptInlineImportmapTag
	extend Phlex::Rails::HelperMacros

	# [Docs](https://www.rubydoc.info/gems/importmap-rails/Importmap%2FImportmapTagsHelper:javascript_inline_importmap_tag)
	register_output_helper def javascript_inline_importmap_tag(...) = nil
end
