# frozen_string_literal: true

module Phlex::Rails::Helpers::TurboRefreshMethodTag
	extend Phlex::Rails::HelperMacros

	# [Turbo Docs](https://rubydoc.info/github/hotwired/turbo-rails/Turbo%2FDriveHelper:turbo_refresh_method_tag)
	register_output_helper def turbo_refresh_method_tag(...) = nil
end
