# frozen_string_literal: true

module Phlex::Rails::Helpers::CollectionRadioButtons
	extend Phlex::Rails::HelperMacros

	# [Rails Docs](https://api.rubyonrails.org/classes/ActionView/Helpers/FormOptionsHelper.html#method-i-collection_radio_buttons)
	register_builder_yielding_helper def collection_radio_buttons(...) = nil
end
