# frozen_string_literal: true

module Phlex::Rails::Helpers::WeekdayOptionsForSelect
	extend Phlex::Rails::HelperMacros

	# [Rails Docs](https://api.rubyonrails.org/classes/ActionView/Helpers/FormOptionsHelper.html#method-i-weekday_options_for_select)
	register_output_helper def weekday_options_for_select(...) = nil
end
