# frozen_string_literal: true

module Phlex::Rails::Helpers::JavaScriptImportmapModulePreloadTags
	extend Phlex::Rails::HelperMacros

	# [Docs](https://www.rubydoc.info/gems/importmap-rails/Importmap%2FImportmapTagsHelper:javascript_importmap_module_preload_tags)
	register_output_helper def javascript_importmap_module_preload_tags(...) = nil
end
